.. _swh-web-api-urls:

swh-web API URLs
================

.. include:: uri-scheme-api-content.rst

.. include:: uri-scheme-api-directory.rst

.. include:: uri-scheme-api-graph.rst

.. include:: uri-scheme-api-identifiers.rst

.. include:: uri-scheme-api-origin.rst

.. include:: uri-scheme-api-release.rst

.. include:: uri-scheme-api-revision.rst

.. include:: uri-scheme-api-snapshot.rst

.. include:: uri-scheme-api-stat.rst

.. include:: uri-scheme-api-vault.rst
